mkdir build-shared
cd build-shared

cmake -G "Ninja" ^
      -DCMAKE_PREFIX_PATH=%LIBRARY_PREFIX% ^
      -DCMAKE_INSTALL_PREFIX="%LIBRARY_PREFIX%" ^
      -DOPENSSL_INCLUDE_DIR=%LIBRARY_INC% ^
      -DOPENSSL_ROOT_DIR=%LIBRARY_PREFIX% ^
      -DCMAKE_INSTALL_LIBDIR=lib ^
      -DCMAKE_BUILD_TYPE=Release ^
      -DBUILD_SHARED_LIBS=ON ^
      ..
if errorlevel 1 exit 1
ninja install
if errorlevel 1 exit 1
